Changelog
=========


Release Version 1.1.3
------------
- Updated Makefile. [Souradip Pal]
- Fixed device settings. [Souradip Pal]
- Minor change. [Souradip Pal]
- Fixed device map issue. [Souradip Pal]
- Minor fixes. [Souradip Pal]
- Merge pull request #14 from
  souradipp76/dependabot/github_actions/codecov/codecov-action-5.
  [Souradip Pal]

  Bump codecov/codecov-action from 4 to 5
- Bump codecov/codecov-action from 4 to 5. [dependabot[bot]]

  Bumps [codecov/codecov-action](https://github.com/codecov/codecov-action) from 4 to 5.
  - [Release notes](https://github.com/codecov/codecov-action/releases)
  - [Changelog](https://github.com/codecov/codecov-action/blob/main/CHANGELOG.md)
  - [Commits](https://github.com/codecov/codecov-action/compare/v4...v5)

  ---
  updated-dependencies:
  - dependency-name: codecov/codecov-action
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...
- Adjusted prompts. [Souradip Pal]
- Fixed tests and updated CONTRIBUTING.md. [Souradip Pal]
- Fixing utils. [Souradip Pal]
- Minor fix. [Souradip Pal]
- Updated example. [Souradip Pal]
- Updated README and added example. [Souradip Pal]
- Modified paper.md. [Souradip Pal]
- Removed tokens. [Souradip Pal]
- Update VERSION. [Sayak Chakrabarty]
- Update main.yml. [Sayak Chakrabarty]
- Rename project. [Souradip Pal]
- Update setup.py. [Sayak Chakrabarty]
- Update README.md. [Sayak Chakrabarty]
- Update VERSION. [Sayak Chakrabarty]
- Update main.yml. [Sayak Chakrabarty]
- Updated README. [Souradip Pal]
- Fixed tests and bib. [Souradip Pal]
- Tests. [hellokayas]
- Tests. [hellokayas]
- Tests. [hellokayas]
- Partially fixed tests. [Souradip Pal]
- Tests. [hellokayas]
- Merge branch 'main' of https://github.com/souradipp76/doc_generator.
  [hellokayas]
- Corrected qa mode and test. [Souradip Pal]
- Fixed scripts and README. [Souradip Pal]
- Added missing tests and fixed formatting. [Souradip Pal]
- Tests. [hellokayas]
- Fixed tests and workflow. [Souradip Pal]
- Merge branch 'main' of https://github.com/souradipp76/ReadMeReady.
  [Souradip Pal]
- Tests. [hellokayas]
- Merge branch 'main' of https://github.com/souradipp76/ReadMeReady.
  [Souradip Pal]
- Merge branch 'main' of https://github.com/souradipp76/doc_generator.
  [hellokayas]
- Tests. [hellokayas]
- Updated workflow for win platform. [Souradip Pal]
- Updated workflow. [Souradip Pal]
- Modified workflow env. [Souradip Pal]
- Added OPENAI_API_KEY in workflow env. [Souradip Pal]
- Fixed tests. [Souradip Pal]
- Test. [hellokayas]
- Tests. [hellokayas]
- Fixed utils test. [Souradip Pal]
- Tests. [hellokayas]
- Tests. [hellokayas]
- Fixed linting errors. [Souradip Pal]
- Added support for GGUF file and refactored code. [Souradip Pal]
- Changed workflow. [Souradip Pal]
- Changed python version in workflow. [Souradip Pal]
- Merge branch 'main' of https://github.com/souradipp76/ReadMeReady.
  [Souradip Pal]
- Update paper.md. [Sayak Chakrabarty]
- Update paper.md. [Sayak Chakrabarty]
- Updated workflow. [Souradip Pal]
- Updated README. [Souradip Pal]
- Added reference to paper. [Souradip Pal]
- Modified paper. [Souradip Pal]
- Delete paper/figures/test.jpg. [Sayak Chakrabarty]
- Add files via upload. [Sayak Chakrabarty]
- Create test.jpg. [Sayak Chakrabarty]
- Update paper.bib. [Sayak Chakrabarty]
- Update paper.bib. [Sayak Chakrabarty]
- Update paper.md. [Sayak Chakrabarty]
- Added paper. [Souradip Pal]
- Changed to Apache 2.0 licence. [Souradip Pal]
- Minor fix. [Souradip Pal]
- Added markdown to json converted. [Souradip Pal]
- Some changes in data script. [Souradip Pal]
- Added markdown check. [Souradip Pal]
- Removed unused file. [Souradip Pal]
- This is for processing VQA dataset. Delete later. [Sayak Chakrabarty]
- Minor changes. [Souradip Pal]
- Some changes. [Souradip Pal]
- Minor fix in README. [Souradip Pal]
- Updated README. [Souradip Pal]
- Fixed test error. [test]
- Removed unused test. [test]
- Minor change in datatype. [test]
- Resolving lint errors. [test]
- Cleaning up repo. [test]
- Updated README file. [test]
- Final. [hellokayas]
- Data.ipynb. [hellokayas]
- Some minor changes. [hellokayas]
- Some changes in  query prompts. [hellokayas]
- Changed prompting library in main. [hellokayas]
- Added text cleaning and evaluation scripts. [hellokayas]
- Updated scripts for finetuning. [Sayak Chakrabarty]
- Some minor change. [souradipp76]
- Some change. [souradipp76]
- Some changes. [souradipp76]
- Minor fixes and addition of quantization config. [souradipp76]
- Minor changes. [souradipp76]
- Added original models. [souradipp76]
- Some corrections. [souradipp76]
- Some minor corrections. [souradipp76]
- Added gemma models. [souradipp76]
- Added script for cleaning data. [souradipp76]
- Data Cleaning code. [Sayak Chakrabarty]
- Updated version in workflows. [souradipp76]
- Corrected version in workflows. [souradipp76]
- Minor changes. [souradipp76]
- Minor change. [souradipp76]
- Some changes. [souradipp76]
- Removed tests_mac from workflows. [souradipp76]
- Updated requirements. [souradipp76]
- Resolve linting errors. [souradipp76]
- Fixed linting errors. [souradipp76]
- Fixed some linting errors. [souradipp76]
- Fixed some linting errors. [souradipp76]
- Linting code. [souradipp76]
- Removed unused file. [souradipp76]
- Fixes for running other models options. [souradipp76]
- Corrected models options. [souradipp76]
- Some changes in user inputs and model options. [souradip_pal]
- Setting up mkdocs for testing. [souradip_pal]
- Added multiple models options. [souradipp76]
- Fixed output for README generation. [souradipp76]
- Changes in script. [souradip_pal]
- Changed path in script. [souradip_pal]
- Added script for dataset creation. [souradip_pal]
- Notebook. [Sayak Chakrabarty]
- Updated data.ipynb. [souradip_pal]
- Some changes to generate readme. [souradip_pal]
- Scripts folder. [Sayak Chakrabarty]
- Merge pull request #6 from
  souradipp76/dependabot/github_actions/actions/checkout-4. [Souradip
  Pal]

  Bump actions/checkout from 3 to 4
- Bump actions/checkout from 3 to 4. [dependabot[bot]]

  Bumps [actions/checkout](https://github.com/actions/checkout) from 3 to 4.
  - [Release notes](https://github.com/actions/checkout/releases)
  - [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
  - [Commits](https://github.com/actions/checkout/compare/v3...v4)

  ---
  updated-dependencies:
  - dependency-name: actions/checkout
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...
- Fixed questions for README generation. [souradipp76]
- Changed prompt for readme. [souradip_pal]
- Repos. [Sayak Chakrabarty]
- Context dataset sample. [souradipp76]
- Updates. [Sayak Chakrabarty]
- Ipynb. [Sayak Chakrabarty]
- Data.py. [Sayak Chakrabarty]
- Some minor adjustments. [souradipp76]
- Changed chunk size to fit in max length. [souradip_pal]
- Fixes in HNSWLib. [souradip_pal]
- Some changes in chain. [souradip_pal]
- Some changes for query. [souradipp76]
- Some changes in HNSWLib. [souradip_pal]
- Fixes for vector store. [souradipp76]
- Some changes in vectore store indexing. [souradip_pal]
- Fixes for LLama2. [souradipp76]
- Some fixes in llama2. [souradip_pal]
- Using llama2 chat model. [souradip_pal]
- Fixed indexing issues. [souradip_pal]
- Some changes. [souradip_pal]
- Resolved conflicts. [souradip_pal]
- Prompt engineering. [Sayak Chakrabarty]
- Merge branch 'main' of https://github.com/souradipp76/doc_generator
  into main. [Sayak Chakrabarty]
- Merge branch 'main' of https://github.com/souradipp76/doc_generator
  into main. [Sayak Chakrabarty]
- Updates. [Sayak Chakrabarty]
- Update. [Sayak Chakrabarty]
- Updates. [Sayak Chakrabarty]
- Some fixes in process repository. [souradip_pal]
- Fixed variable names. [souradip_pal]
- Some changes. [souradip_pal]
- Changes in main. [souradip_pal]
- Fixed enum. [souradip_pal]
- Delete. [Sayak Chakrabarty]
- Merge branch 'main' of https://github.com/souradipp76/doc_generator.
  [souradip_pal]
- Update. [Sayak Chakrabarty]
- Minor fixes. [souradip_pal]
- Fixed create vector store. [souradip_pal]
- Minor fix in process repository. [souradip_pal]
- Minor change in process repository. [souradip_pal]
- Merge branch 'main' of https://github.com/souradipp76/doc_generator.
  [souradip_pal]
- API. [Sayak Chakrabarty]
- Fixed process repository. [souradip_pal]
- Prompt and selectModel. [Sayak Chakrabarty]
- Resolved conflicts. [souradip_pal]
- Updates. [Sayak Chakrabarty]
- Added index methods. [souradip_pal]
- Merge branch 'main' of https://github.com/souradipp76/doc_generator.
  [souradip_pal]
- Index. [Sayak Chakrabarty]
- Restructured directories. [souradip_pal]
- Traverse. [Sayak Chakrabarty]
- Added file utils. [souradip_pal]
- Fixed dimension error. [souradip_pal]
- Almost running. [Sayak Chakrabarty]
- Merge branch 'main' of https://github.com/souradipp76/doc_generator
  into main. [Sayak Chakrabarty]
- Some changes. [souradip_pal]
- Updates. [Sayak Chakrabarty]
- Updates. [Sayak Chakrabarty]
- Updates. [Sayak Chakrabarty]
- HNSW. [Sayak Chakrabarty]
- Index + createchatchain. [Sayak Chakrabarty]
- Utils. [Sayak Chakrabarty]
- LLMUtils.py. [Sayak Chakrabarty]
- Merge pull request #2 from
  souradipp76/dependabot/github_actions/actions/setup-python-5.
  [Souradip Pal]

  Bump actions/setup-python from 4 to 5
- Merge branch 'main' into dependabot/github_actions/actions/setup-
  python-5. [Souradip Pal]
- Merge pull request #1 from
  souradipp76/dependabot/github_actions/stefanzweifel/git-auto-commit-
  action-5. [Souradip Pal]

  Bump stefanzweifel/git-auto-commit-action from 4 to 5
- ✅ Ready to clone and code. [dependabot[bot]]
- Bump stefanzweifel/git-auto-commit-action from 4 to 5.
  [dependabot[bot]]

  Bumps [stefanzweifel/git-auto-commit-action](https://github.com/stefanzweifel/git-auto-commit-action) from 4 to 5.
  - [Release notes](https://github.com/stefanzweifel/git-auto-commit-action/releases)
  - [Changelog](https://github.com/stefanzweifel/git-auto-commit-action/blob/master/CHANGELOG.md)
  - [Commits](https://github.com/stefanzweifel/git-auto-commit-action/compare/v4...v5)

  ---
  updated-dependencies:
  - dependency-name: stefanzweifel/git-auto-commit-action
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...
- Merge pull request #3 from
  souradipp76/dependabot/github_actions/actions/checkout-4. [Souradip
  Pal]

  Bump actions/checkout from 3 to 4
- ✅ Ready to clone and code. [dependabot[bot]]
- Bump actions/checkout from 3 to 4. [dependabot[bot]]

  Bumps [actions/checkout](https://github.com/actions/checkout) from 3 to 4.
  - [Release notes](https://github.com/actions/checkout/releases)
  - [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
  - [Commits](https://github.com/actions/checkout/compare/v3...v4)

  ---
  updated-dependencies:
  - dependency-name: actions/checkout
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...
- Merge pull request #4 from
  souradipp76/dependabot/github_actions/codecov/codecov-action-4.
  [Souradip Pal]

  Bump codecov/codecov-action from 3 to 4
- ✅ Ready to clone and code. [dependabot[bot]]
- Bump codecov/codecov-action from 3 to 4. [dependabot[bot]]

  Bumps [codecov/codecov-action](https://github.com/codecov/codecov-action) from 3 to 4.
  - [Release notes](https://github.com/codecov/codecov-action/releases)
  - [Changelog](https://github.com/codecov/codecov-action/blob/main/CHANGELOG.md)
  - [Commits](https://github.com/codecov/codecov-action/compare/v3...v4)

  ---
  updated-dependencies:
  - dependency-name: codecov/codecov-action
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...
- Merge pull request #5 from
  souradipp76/dependabot/github_actions/softprops/action-gh-release-2.
  [Souradip Pal]

  Bump softprops/action-gh-release from 1 to 2
- ✅ Ready to clone and code. [dependabot[bot]]
- Bump softprops/action-gh-release from 1 to 2. [dependabot[bot]]

  Bumps [softprops/action-gh-release](https://github.com/softprops/action-gh-release) from 1 to 2.
  - [Release notes](https://github.com/softprops/action-gh-release/releases)
  - [Changelog](https://github.com/softprops/action-gh-release/blob/master/CHANGELOG.md)
  - [Commits](https://github.com/softprops/action-gh-release/compare/v1...v2)

  ---
  updated-dependencies:
  - dependency-name: softprops/action-gh-release
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...
- ✅ Ready to clone and code. [souradipp76]
- ✅ Ready to clone and code. [dependabot[bot]]
- Bump actions/setup-python from 4 to 5. [dependabot[bot]]

  Bumps [actions/setup-python](https://github.com/actions/setup-python) from 4 to 5.
  - [Release notes](https://github.com/actions/setup-python/releases)
  - [Commits](https://github.com/actions/setup-python/compare/v4...v5)

  ---
  updated-dependencies:
  - dependency-name: actions/setup-python
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...
- Initial commit. [Souradip Pal]


